# pykkn

PYKKN is a library that supports researchers to store their data in a HDF5 file using Python. The library can handle different types of inputs like array, matrix, image and video.

## Documentation
The documentation can be found [here](https://fst-tuda.pages.rwth-aachen.de/public/pykkn/).

# Repository
https://git.rwth-aachen.de/fst-tuda/public/pykkn